((doc) => {
    function createTextSetter(selector) {
        const elem = doc.querySelector(selector);
        let text;
        return newText => {
            if (newText !== text) {
                text = newText;
                elem.textContent = newText;
                return true;
            }
            return false;
        };
    }
    doc.addEventListener('DOMContentLoaded', () => {
        const setters = {
            y: createTextSetter('#dy'),
            M: createTextSetter('#dm'),
            d: createTextSetter('#dd'),
            h: createTextSetter('#th'),
            m: createTextSetter('#tm'),
            s: createTextSetter('#ts'),
        }
        const timeMask = {
            d: doc.querySelector('#time>.mask.d>.p'),
            h: doc.querySelector('#time>.mask.h>.p'),
            m: doc.querySelector('#time>.mask.m>.p')
        };
        const updateText = () => {
            const now = new Date();
            setters.y(now.getFullYear());
            setters.M((now.getMonth() + 1).toFixed().padStart(2, '0'));
            setters.d(now.getDate().toFixed().padStart(2, '0'));
            setters.h(now.getHours().toFixed().padStart(2, '0'));
            setters.m(now.getMinutes().toFixed().padStart(2, '0'));
            if (setters.s(now.getSeconds().toFixed().padStart(2, '0'))) {
                timeMask.d.style.maxWidth = `${((now.getSeconds() + (60 * now.getMinutes()) + (3600 * now.getHours())) / 86400) * 100}%`;
                timeMask.h.style.maxWidth = `${((now.getSeconds() + (60 * now.getMinutes())) / 3600) * 100}%`;
                timeMask.m.style.maxWidth = `${(now.getSeconds() / 60) * 100}%`;
            }
        };
        setInterval(updateText, 1000);
        updateText();
    });
})(document);